%?mingw_package_header

Name:           mingw-gnutls
Version:        3.1.11
Release:        %mkrel 6
Summary:        MinGW GnuTLS TLS/SSL encryption library

# The libraries are LGPLv2.1+, utilities are GPLv3+, however
# the bundled gnulib is LGPLv3+
License: GPLv3+ and LGPLv2+ and LGPLv3+
Group:          Development/Other
URL:            http://www.gnutls.org/
#Source0:        ftp://ftp.gnutls.org/pub/gnutls/gnutls-%{version}.tar.bz2
# We use the same source tarball as Fedora native package, which
# has the patent tainted SRP code removed.
Source0:        gnutls-%{version}-hobbled.tar.xz
Source2: hobble-gnutls

BuildArch:      noarch

Patch1: gnutls-3.1.7-rpath.patch
# Use only FIPS approved ciphers in the FIPS mode
Patch7: gnutls-2.12.21-fips-algorithms.patch
# Make ECC optional as it is now hobbled
Patch8: gnutls-3.1.11-noecc.patch
# Use random port in some tests to avoid conflicts during simultaneous builds on the same machine
Patch9: gnutls-3.1.10-tests-rndport.patch

# MinGW-specific patches.
Patch1000:      gnutls-3.1.7-mingw-iconv.patch
Patch1002:      gnutls-fix-external-libtasn1-detection.patch

# Fix FTBFS due to invalid use of cdecl
Patch1003:      gnutls-use-proper-cdecl.patch

BuildRequires:  mingw32-filesystem >= 95
BuildRequires:  mingw32-gcc
BuildRequires:  mingw32-gcc-c++
BuildRequires:  mingw32-binutils
BuildRequires:  mingw32-libgpg-error
BuildRequires:  mingw32-libtasn1 >= 3.1
BuildRequires:  mingw32-gettext
BuildRequires:  mingw32-win-iconv
BuildRequires:  mingw32-readline
BuildRequires:  mingw32-zlib
BuildRequires:  mingw32-p11-kit
BuildRequires:  mingw32-nettle >= 2.5

BuildRequires:  mingw64-filesystem >= 95
BuildRequires:  mingw64-gcc
BuildRequires:  mingw64-gcc-c++
BuildRequires:  mingw64-binutils
BuildRequires:  mingw64-libgpg-error
BuildRequires:  mingw64-libtasn1 >= 3.1
BuildRequires:  mingw64-gettext
BuildRequires:  mingw64-win-iconv
BuildRequires:  mingw64-readline
BuildRequires:  mingw64-zlib
BuildRequires:  mingw64-p11-kit
BuildRequires:  mingw64-nettle >= 2.5

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool

# Yes, really ...
BuildRequires:  pkgconfig

# For native /usr/bin/msgfmt etc.
BuildRequires:  gettext


%description
GnuTLS TLS/SSL encryption library.  This library is cross-compiled
for MinGW.


# Win32
%package -n mingw32-gnutls
Summary:        MinGW GnuTLS TLS/SSL encryption library
Requires:       pkgconfig

%description -n mingw32-gnutls
GnuTLS TLS/SSL encryption library.  This library is cross-compiled
for MinGW.

# Win64
%package -n mingw64-gnutls
Summary:        MinGW GnuTLS TLS/SSL encryption library
Requires:       pkgconfig

%description -n mingw64-gnutls
GnuTLS TLS/SSL encryption library.  This library is cross-compiled
for MinGW.


%?mingw_debug_package


%prep
%setup -q -n gnutls-%{version}

%patch1 -p1 -b .rpath
# This patch is not applicable as we use nettle now but some parts will be
# later reused.
#%patch7 -p1 -b .fips
%patch8 -p1 -b .noecc
%patch9 -p1 -b .rndport

%patch1000 -p0 -b .iconv
%patch1002 -p0 -b .libtasn1
%patch1003 -p0 -b .cdecl

%{SOURCE2} -e

%build
%mingw_configure                   \
    --disable-static               \
    --disable-openssl-compatibility \
    --disable-srp-authentication   \
    --disable-nls \
    --disable-rpath \
    --disable-ecdhe

# %{?_smp_mflags} doesn't build correctly.
%mingw_make


%install
%mingw_make_install DESTDIR=$RPM_BUILD_ROOT

# Remove .la files
rm -f $RPM_BUILD_ROOT%{mingw32_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{mingw64_libdir}/*.la

# The .def files aren't interesting for other binaries
rm -f $RPM_BUILD_ROOT%{mingw32_bindir}/*.def
rm -f $RPM_BUILD_ROOT%{mingw64_bindir}/*.def

# Remove info and man pages which duplicate stuff in Fedora already.
rm -rf $RPM_BUILD_ROOT%{mingw32_infodir}
rm -rf $RPM_BUILD_ROOT%{mingw32_mandir}

rm -rf $RPM_BUILD_ROOT%{mingw64_infodir}
rm -rf $RPM_BUILD_ROOT%{mingw64_mandir}


%files -n mingw32-gnutls
%doc COPYING COPYING.LESSER
%{mingw32_bindir}/certtool.exe
%{mingw32_bindir}/danetool.exe
%{mingw32_bindir}/gnutls-cli-debug.exe
%{mingw32_bindir}/gnutls-cli.exe
%{mingw32_bindir}/gnutls-serv.exe
%{mingw32_bindir}/libgnutls-28.dll
%{mingw32_bindir}/libgnutls-xssl-0.dll
%{mingw32_bindir}/libgnutlsxx-28.dll
%{mingw32_bindir}/ocsptool.exe
%{mingw32_bindir}/p11tool.exe
%{mingw32_bindir}/psktool.exe
%{mingw32_libdir}/libgnutls.dll.a
%{mingw32_libdir}/libgnutls-xssl.dll.a
%{mingw32_libdir}/libgnutlsxx.dll.a
%{mingw32_libdir}/pkgconfig/gnutls.pc
%{mingw32_includedir}/gnutls/

%files -n mingw64-gnutls
%doc COPYING COPYING.LESSER
%{mingw64_bindir}/certtool.exe
%{mingw64_bindir}/danetool.exe
%{mingw64_bindir}/gnutls-cli-debug.exe
%{mingw64_bindir}/gnutls-cli.exe
%{mingw64_bindir}/gnutls-serv.exe
%{mingw64_bindir}/libgnutls-28.dll
%{mingw64_bindir}/libgnutls-xssl-0.dll
%{mingw64_bindir}/libgnutlsxx-28.dll
%{mingw64_bindir}/ocsptool.exe
%{mingw64_bindir}/p11tool.exe
%{mingw64_bindir}/psktool.exe
%{mingw64_libdir}/libgnutls.dll.a
%{mingw64_libdir}/libgnutls-xssl.dll.a
%{mingw64_libdir}/libgnutlsxx.dll.a
%{mingw64_libdir}/pkgconfig/gnutls.pc
%{mingw64_includedir}/gnutls/




%changelog
* Mon Sep 23 2013 neoclust <neoclust> 3.1.11-6.mga4
+ Revision: 483841
- imported package mingw-gnutls


* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.11-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Jun 17 2013 Kalev Lember <kalevlember@gmail.com> - 3.1.11-5
- One more rebuild for InterlockedCompareExchange

* Sun Jun 16 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.1.11-4
- Rebuild to resolve InterlockedCompareExchange regression in mingw32 libraries

* Sat Jun 15 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.1.11-3
- Fix FTBFS due to invalid use of cdecl

* Sat Jun 15 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.1.11-2
- Rebuild to resolve InterlockedCompareExchange regression in mingw32 libraries

* Thu May 30 2013 Michael Cronenworth <mike@cchtml.com> - 3.1.11-1
- Update to 3.1.11

* Thu May 09 2013 Michael Cronenworth <mike@cchtml.com> - 3.1.10-1
- Update to 3.1.10
- license of the library is back to LGPLv2.1+

* Mon Mar 04 2013 Michael Cronenworth <mike@cchtml.com> - 3.1.8-1
- Update to 3.1.8
- Update No-ECC patch (#913797)

* Thu Feb 07 2013 Michael Cronenworth <mike@cchtml.com> - 3.1.7-1
- Update to 3.1.7

* Sun Jan 27 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.12.21-3
- Rebuild against mingw-gcc 4.8 (win64 uses SEH exceptions now)

* Thu Nov 22 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.12.21-2
- Rebuild against the latest mingw-readline

* Sat Nov 10 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.12.21-1
- Update to 2.12.21

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.12.20-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Jun 19 2012 Michael Cronenworth <mike@cchtml.com> - 2.12.20-1
- New upstream version.

* Sun May 20 2012 Michael Cronenworth <mike@cchtml.com> - 2.12.19-1
- New upstream version.

* Sun May 13 2012 Michael Cronenworth <mike@cchtml.com> - 2.12.18-1
- New upstream version.

* Thu Mar 29 2012 Michael Cronenworth <mike@cchtml.com> - 2.12.17-1
- New upstream version.
- Use system libtasn1.

* Sun Mar 11 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.12.14-7
- Added win64 support
- Dropped .def files

* Fri Mar 09 2012 Kalev Lember <kalevlember@gmail.com> - 2.12.14-6
- Remove .la files

* Wed Mar 07 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.12.14-5
- Renamed the source package to mingw-gnutls (RHBZ #800878)
- Use mingw macros without leading underscore
- Dropped unneeded RPM tags

* Tue Feb 28 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.12.14-4
- Rebuild against the mingw-w64 toolchain
- Fix compatibility with mingw-w64

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.12.14-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sat Dec 03 2011 Michael Cronenworth <mike@cchtml.com> - 2.12.14-2
- Include new tool from p11-kit support.

* Sat Dec 03 2011 Michael Cronenworth <mike@cchtml.com> - 2.12.14-1
- Update to 2.12.14
- Allow p11-kit support.

* Wed Nov 02 2011 Michael Cronenworth <mike@cchtml.com> - 2.12.12-1
- Update to 2.12.12

* Mon Oct 24 2011 Michael Cronenworth <mike@cchtml.com> - 2.12.11-1
- Update to 2.12.11

* Wed Jul 06 2011 Kalev Lember <kalevlember@gmail.com> - 2.10.5-2
- Rebuilt against win-iconv

* Thu Apr 28 2011 Kalev Lember <kalev@smartlink.ee> - 2.10.5-1
- Update to 2.10.5

* Wed Apr 27 2011 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.6.4-7
- Dropped the proxy-libintl pieces

* Fri Apr 22 2011 Kalev Lember <kalev@smartlink.ee> - 2.6.4-6
- Rebuilt for pseudo-reloc version mismatch (#698827)

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.6.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Nov  7 2010 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.6.4-4
- Rebuild in order to have soft dependency on libintl

* Fri Oct  9 2009 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.6.4-3
- Use %%global instead of %%define
- Automatically generate debuginfo subpackage

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.6.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Mar  9 2009 Richard W.M. Jones <rjones@redhat.com> - 2.6.4-1
- New Fedora native version 2.6.4.

* Fri Feb 20 2009 Richard W.M. Jones <rjones@redhat.com> - 2.6.3-5
- Rebuild for mingw32-gcc 4.4

* Thu Feb 19 2009 Richard W.M. Jones <rjones@redhat.com> - 2.6.3-4
- +BR mingw32-gcc-c++

* Fri Feb  6 2009 Richard W.M. Jones <rjones@redhat.com> - 2.6.3-3
- Include license.

* Fri Jan 23 2009 Richard W.M. Jones <rjones@redhat.com> - 2.6.3-2
- Rebase to native Fedora version 2.6.3.
- Enable C++ library.
- Use find_lang macro.
- Don't build static library.
- Rebase MinGW patch to 2.6.3.
- +BR mingw32-dlfcn.
- +BR mingw32-readline.
- Force rebuild of libtool.

* Tue Jan 13 2009 Richard W.M. Jones <rjones@redhat.com> - 2.4.2-4
- Requires pkgconfig.

* Thu Nov 13 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.2-3
- fix chain verification issue CVE-2008-4989 (#470079)
- separate out the MinGW-specific patch from the others

* Wed Sep 24 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.2-2
- Rename mingw -> mingw32.

* Wed Sep 24 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.2-1
- New native version.

* Mon Sep 22 2008 Daniel P. Berrange <berrange@redhat.com> - 2.4.1-9
- Switch to source tar.bz2 with SRP stuff removed

* Sun Sep 21 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.1-8
- Remove duplicate manpages and info files.

* Thu Sep 11 2008 Daniel P. Berrange <berrange@redhat.com> - 2.4.1-7
- Add BR on autoconf, automake and libtool

* Wed Sep 10 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.1-6
- Need to run autoreconf after patching src/Makefile.am.
- Remove static libs.

* Fri Sep  5 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.1-5
- Add patch to build certtool.exe because of missing dep of gnulib on intl.
- BuildArch is noarch.

* Thu Sep  4 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.1-3
- Use mingw-filesystem RPM macros.
- Depends on mingw-iconv, mingw-gettext.

* Tue Sep  2 2008 Daniel P. Berrange <berrange@redhat.com> - 2.4.1-2
- List files explicitly and use custom CFLAGS

* Mon Jul  7 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.1-1
- Initial RPM release, largely based on earlier work from several sources.
